package VMOMI::DVPortStatusVmDirectPathGen2InactiveReasonOther;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
